# __init__.py: tell python the whole directory here should be treated as a package
from .main import aloha # this line is more like a function registry for letting developer to import o the function aloha and use it ~

# when we use the package, how?
# do the following import
# from alohapy import aloha


# This file is used for how to bundling and publishing the package ~
from setuptools import setup, find_packages

setup(
  name="alohapy",
  version="0.2.1",
  packages=find_packages(),
  install_requires=[],
  entry_points={ # this would create a cli command for your aloha function and directly used by terminal ~
    "console_scripts": [
      "aloha-cli = alohapy:aloha"
    ]
  }
)
